Class: Protocol::HTTP3::Server
- Inherits:
-
Object
- Object
- Protocol::HTTP3::Server
- Defined in:
- lib/protocol/http3.rb
Overview
An HTTP/3 server connection.
Instance Method Summary collapse
- #native_submit_response ⇒ Object
-
#submit_response(stream_id, headers, body = nil) ⇒ Object
Submit a response for the given stream and return the stream used for the response body.
Instance Method Details
#native_submit_response ⇒ Object
33 |
# File 'lib/protocol/http3.rb', line 33 alias native_submit_response submit_response |
#submit_response(stream_id, headers, body = nil) ⇒ Object
Submit a response for the given stream and return the stream used for the response body.
36 37 38 39 40 |
# File 'lib/protocol/http3.rb', line 36 def submit_response(stream_id, headers, body = nil) Stream.new(self, stream_id).tap do native_submit_response(stream_id, headers, body) end end |